@@ -203,7 +203,7 @@ async def async_load_annotations(
         [key in EXCLUDE_BUILD_FIELDS for key in data[0].keys()]
     ):
         build = None
-    await sdk.call_with_retry(
+    response = await sdk.call_with_retry(
         sdk.annotations.load_annotations,
         data=override_hgvs([{**d, "build": build} for d in data]),
         data_set=data_set,
@@ -215,7 +215,7 @@ async def async_load_annotations(
     )
 
     # response of warehouse is blank, returning data for downstream processing
-    return data
+    return data, response
 
 
 @curry
@@ -457,9 +457,10 @@ def up_build(call: dict):
     return call
 
 
-def to_csra(call: dict, add_build=True):
+def to_csra(call: dict, add_build=True, add_chr=True):
+    chromosome = f"chr{call.get('chr')}" if add_chr else call.get("chr")
     csra_data = (
-        f"chr{call.get('chr')}",
+        chromosome,
         str(call.get("start")),
         call.get("ref") or "-",
         call.get("alt") or "-",
