@@ -3,7 +3,11 @@ from .bed import BedFileSource
 from .delimited import DelimitedFileSource
 from .paths import CollectFilePathsSource
 from .excel import ExcelSource
-from .aggregated import AggregatedCOSMICSources, AggregatedFileSource
+from .aggregated import (
+    AggregatedCOSMICSources,
+    AggregatedFileSource,
+    AggregatedOmimFileSource,
+)
 from .maf import MAFSource
 from .xml import XMLSource
 from . import one_off_sources
@@ -23,6 +27,7 @@ __all__ = (
     "MAFSource",
     "XMLSource",
     "AnnotationsFilterFileSource",
+    "AggregatedOmimFileSource",
 )
 
 
