@@ -1,5 +1,9 @@
 import xml.etree.cElementTree as etree
 
+from cytoolz import curry
+
+from genomoncology.pipeline.sources.base import LazyFileSource
+
 VARIANT_TYPE_BLACKLIST = [
     "Phase unknown",
     "Haplotype",
@@ -23,6 +27,7 @@ ID = "ID"
 GENE = "Gene"
 GENE_LIST = "GeneList"
 GRCH_37 = "GRCh37"
+GRCH_38 = "GRCh38"
 INCLUDED_RECORD = "IncludedRecord"
 INTERPRETATION = "Interpretation"
 INTERPRETATIONS = "Interpretations"
@@ -57,9 +62,11 @@ XREF_LIST = "XRefList"
 XREF = "XRef"
 
 
-class ClinvarXMLSource:
-    def __init__(self, file_path, **kwargs):
+@curry
+class ClinvarXMLSource(LazyFileSource):
+    def __init__(self, file_path, is_grch38=False, **kwargs):
         self.file_path = file_path
+        self.is_grch38 = is_grch38
 
     def __iter__(self):
         return self.parse_clinvar_xml()
@@ -190,8 +197,8 @@ class ClinvarXMLSource:
 
     def get_genes(self, interpreted_record):
         """
-            Returns list of gene names and
-            whether the gene was submitted or not.
+        Returns list of gene names and
+        whether the gene was submitted or not.
         """
         try:
             genes = (
@@ -206,6 +213,9 @@ class ClinvarXMLSource:
         except Exception:
             return [], False
 
+    def get_assembly(self):
+        return GRCH_38 if self.is_grch38 else GRCH_37
+
     def create_csra(self, interpreted_record):
         try:
             sequence_locations = (
@@ -214,10 +224,12 @@ class ClinvarXMLSource:
                 .findall(SEQUENCE_LOCATION)
             )
             if sequence_locations:
+                assembly_name = self.get_assembly()
+
                 valid_sequence_locations = [
                     sl
                     for sl in sequence_locations
-                    if sl.attrib.get(ASSEMBLY) == GRCH_37
+                    if sl.attrib.get(ASSEMBLY) == assembly_name
                 ]
                 for sl in valid_sequence_locations:
                     chr, pos = (
@@ -231,7 +243,7 @@ class ClinvarXMLSource:
                     if ref == alt or not all([chr, pos, ref, alt]):
                         return None
                     else:
-                        return f"chr{chr}|{pos}|{ref}|{alt}|GRCh37"
+                        return f"chr{chr}|{pos}|{ref}|{alt}|{assembly_name}"
             else:
                 return None
         except Exception:
@@ -368,6 +380,7 @@ class ClinvarXMLSource:
         if len(genes) > 0:
             record["gene"] = genes
         record["alterations"] = list(alterations)
+        record["csra"] = csra
         record = self.iterate_individual_submissions(
             clinical_assertions, record, interpreted_record
         )
